============
Introduction
============

The purpose of this collection of documents is to provide users of SymPy with topics which are
not strictly tutorial or are longer than tutorials and tests. The documents will hopefully
fill a gap as SymPy matures and users find more ways to show how SymPy can be used in more
advanced topics.
